Renable frexp(f) device math function
Change-Id: I53c022b8ddf38cd17ddb42eba457b9020db66395
[ROCm/hip commit: c25b9c6786]
This commit is contained in:
@@ -60,7 +60,7 @@ __device__ float fmaf(float x, float y, float z);
|
|||||||
__device__ float fmaxf(float x, float y);
|
__device__ float fmaxf(float x, float y);
|
||||||
__device__ float fminf(float x, float y);
|
__device__ float fminf(float x, float y);
|
||||||
__device__ float fmodf(float x, float y);
|
__device__ float fmodf(float x, float y);
|
||||||
//__device__ float frexpf(float x, int* nptr);
|
__device__ float frexpf(float x, int* nptr);
|
||||||
__device__ float hypotf(float x, float y);
|
__device__ float hypotf(float x, float y);
|
||||||
__device__ float ilogbf(float x);
|
__device__ float ilogbf(float x);
|
||||||
__device__ int isfinite(float a);
|
__device__ int isfinite(float a);
|
||||||
@@ -146,7 +146,7 @@ __device__ double fma(double x, double y, double z);
|
|||||||
__device__ double fmax(double x, double y);
|
__device__ double fmax(double x, double y);
|
||||||
__device__ double fmin(double x, double y);
|
__device__ double fmin(double x, double y);
|
||||||
__device__ double fmod(double x, double y);
|
__device__ double fmod(double x, double y);
|
||||||
//__device__ double frexp(double x, int *nptr);
|
__device__ double frexp(double x, int *nptr);
|
||||||
__device__ double hypot(double x, double y);
|
__device__ double hypot(double x, double y);
|
||||||
__device__ double ilogb(double x);
|
__device__ double ilogb(double x);
|
||||||
__device__ int isfinite(double x);
|
__device__ int isfinite(double x);
|
||||||
|
|||||||
@@ -69,7 +69,7 @@ __device__ void double_precision_math_functions()
|
|||||||
fmax(0.0, 0.0);
|
fmax(0.0, 0.0);
|
||||||
fmin(0.0, 0.0);
|
fmin(0.0, 0.0);
|
||||||
fmod(0.0, 1.0);
|
fmod(0.0, 1.0);
|
||||||
// frexp(0.0, &iX);
|
frexp(0.0, &iX);
|
||||||
hypot(1.0, 0.0);
|
hypot(1.0, 0.0);
|
||||||
ilogb(1.0);
|
ilogb(1.0);
|
||||||
isfinite(0.0);
|
isfinite(0.0);
|
||||||
|
|||||||
@@ -70,7 +70,7 @@ __device__ void single_precision_math_functions()
|
|||||||
fmaxf(0.0f, 0.0f);
|
fmaxf(0.0f, 0.0f);
|
||||||
fminf(0.0f, 0.0f);
|
fminf(0.0f, 0.0f);
|
||||||
fmodf(0.0f, 1.0f);
|
fmodf(0.0f, 1.0f);
|
||||||
//frexpf(0.0f, &iX);
|
frexpf(0.0f, &iX);
|
||||||
hypotf(1.0f, 0.0f);
|
hypotf(1.0f, 0.0f);
|
||||||
ilogbf(1.0f);
|
ilogbf(1.0f);
|
||||||
isfinite(0.0f);
|
isfinite(0.0f);
|
||||||
|
|||||||
Reference in New Issue
Block a user